package io.zipcoder.crudapp.Controller;

import io.zipcoder.crudapp.Model.Person;
import io.zipcoder.crudapp.Repository.PersonRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

@RestController
public class PersonController {

    private final PersonRepository personRepository;

    @Autowired
    public PersonController(PersonRepository personRepository) {
        this.personRepository = personRepository;
    }

    @PostMapping("/person")
    public ResponseEntity<Person> createPerson(@RequestBody Person p) {
        return new ResponseEntity<>(this.personRepository.save(p), HttpStatus.CREATED);
    }

    @GetMapping("/person/{id}")
    public ResponseEntity<Person> getPerson(@PathVariable int id) {
        if (this.personRepository.exists(id)) {
            return new ResponseEntity<>(this.personRepository.findOne(id), HttpStatus.OK);
        } else {
            return new ResponseEntity<>(HttpStatus.NOT_FOUND);
        }
    }

    @GetMapping("/person")
    public ResponseEntity<Iterable<Person>> getPersonList() {
        return new ResponseEntity<>(this.personRepository.findAll(), HttpStatus.OK);
    }

    @PutMapping("/person/{id}")
    public ResponseEntity<Person> updatePerson(@PathVariable int id, @RequestBody Person p) {
        if (!this.personRepository.exists(id)) {
            return new ResponseEntity<>(this.personRepository.save(p), HttpStatus.CREATED);
        } else {
            Person person = this.personRepository.findOne(id);
            person.setFirstName(p.getFirstName());
            person.setLastName(p.getLastName());
            return new ResponseEntity<>(this.personRepository.findOne(id), HttpStatus.OK);
        }
    }

    @DeleteMapping("/person/{id}")
    public void deletePerson(@PathVariable int id) {
        this.personRepository.delete(id);
    }

}
